==> application-ui-container-v2.2.1-2.tar.gz: package/lib/AcmActionGroup/AcmActionGroup.js <==
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AcmActionGroup = void 0;
var react_1 = __importStar(require("react"));
var server_1 = __importDefault(require("react-dom/server"));
var react_core_1 = require("@patternfly/react-core");
var styles_1 = require("@material-ui/styles");
var useStyles = styles_1.makeStyles({
    group: {
        '& > div > a, & .pf-c-dropdown__toggle.pf-m-plain': {
            paddingLeft: 0,
            paddingRight: 0,
        },
    },
});
function AcmActionGroup(props) {
    var classes = useStyles();
    var nodes = [];
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    react_1.default.Children.forEach(props.children, function (child) {
        /* istanbul ignore next */
        if (server_1.default.renderToString(child === null || child === void 0 ? void 0 : child.type(child === null || child === void 0 ? void 0 : child.props)).length > 0) {
            nodes.push(child);
        }
    });
    return (react_1.default.createElement(react_core_1.Flex, { className: classes.group }, nodes.map(function (node, i) {
        if (i + 2 > nodes.length) {
            return react_1.default.createElement(react_core_1.FlexItem, { key: i }, node);
        }
        else {
            return (react_1.default.createElement(react_1.Fragment, { key: i },
                react_1.default.createElement(react_core_1.FlexItem, null, node),
                react_1.default.createElement(react_core_1.Divider, { isVertical: true })));
        }
    })));
}
exports.AcmActionGroup = AcmActionGroup;
//# sourceMappingURL=AcmActionGroup.js.map

==> application-ui-container-v2.4.0-40.tar.gz: package/lib/AcmActionGroup/AcmActionGroup.js <==
"use strict";
/* Copyright Contributors to the Open Cluster Management project */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AcmActionGroup = void 0;
var react_1 = __importStar(require("react"));
var react_core_1 = require("@patternfly/react-core");
var styles_1 = require("@material-ui/styles");
var useStyles = styles_1.makeStyles({
    group: {
        '& > div > a, & .pf-c-dropdown__toggle.pf-m-plain': {
            paddingLeft: 0,
            paddingRight: 0,
        },
    },
});
function AcmActionGroup(props) {
    var classes = useStyles();
    return (react_1.default.createElement(react_core_1.Flex, { className: classes.group }, props.children
        .filter(function (child) { return !!child; })
        .map(function (child, i) {
        if (i === 0) {
            return react_1.default.createElement(react_core_1.FlexItem, { key: i }, child);
        }
        else {
            return (react_1.default.createElement(react_1.Fragment, { key: i },
                react_1.default.createElement(react_core_1.Divider, { isVertical: true }),
                react_1.default.createElement(react_core_1.FlexItem, null, child)));
        }
    })));
}
exports.AcmActionGroup = AcmActionGroup;
//# sourceMappingURL=AcmActionGroup.js.map
